@@ -5,6 +5,7 @@ package Plack::Middleware::Statsd;
 # RECOMMEND PREREQ:  Net::Statsd::Tiny v0.3.0
 # RECOMMEND PREREQ:  HTTP::Status 6.16
 # RECOMMEND PREREQ:  List::Util::XS
+# RECOMMEND PREREQ:  Ref::Util::XS
 
 use v5.10;
 
@@ -17,10 +18,11 @@ use List::Util qw/ first /;
 use Plack::Util;
 use Plack::Util::Accessor
     qw/ client sample_rate histogram increment set_add /;
+use Ref::Util qw/ is_coderef /;
 use Time::HiRes;
 use Try::Tiny;
 
-our $VERSION = 'v0.4.1'; # TRIAL
+our $VERSION = 'v0.4.2'; # TRIAL
 
 # Note: You may be able to omit the client if there is a client
 # defined in the environment hash at C<psgix.monitor.statsd>, and the
@@ -40,6 +42,8 @@ sub prepare_app {
             my ( $attr, @methods ) = @$init;
             next if defined $self->$attr;
             my $method = first { $client->can($_) } @methods;
+            warn "No $attr method found for client " . ref($client)
+                unless defined $method;
             $self->$attr(
                 sub {
                     my ($env, @args) = @_;
@@ -60,6 +64,11 @@ sub prepare_app {
             );
         }
     }
+
+    if (my $attr = first { !is_coderef($self->$_) } qw/ histogram increment set_add /) {
+        die "$attr is not a coderef";
+    }
+
 }
 
 sub call {
@@ -169,7 +178,7 @@ Plack::Middleware::Statsd - send statistics to statsd
 
 =head1 VERSION
 
-version v0.4.1
+version v0.4.2
 
 =head1 SYNOPSIS
 
